@@ -3,7 +3,7 @@ import writefreely as wf
 c = wf.client(host="qua.name", user="foo", password="bar")
 
 # saving token to avoid login each time:
-with open("my_token.txt", "w") as fd:
+with open("my_token.txt", "w", encoding="utf-8") as fd:
     fd.write(c.token)
 
 # create an authenticated post
@@ -11,7 +11,7 @@ post = c.create_post(title="Cool Post", body="Awesome content!")
 print("See your post at: {}/{}".format(c.host, post["slug"]))
 
 # next time, load token from file:
-with open("my_token.txt") as fd:
+with open("my_token.txt", encoding="utf-8") as fd:
     c = wf.client(host="qua.name", token=fd.read())
 
 print("User Name:", c.me()["username"])  # User Name: foo
